import React, { useState, useEffect } from "react";
import { BrowserRouter as Router, Routes, Route } from "react-router-dom";
import UserList from "./components/UserList";
import UserDetails from "./components/UserDetails";
import EditUser from "./components/EditUser";
import './styles.css'; // Importing the CSS file

const App = () => {
  const [users, setUsers] = useState([]);

  // Load users from localStorage on component mount
  useEffect(() => {
    const storedUsers = JSON.parse(localStorage.getItem("users")) || [];
    setUsers(storedUsers);
  }, []);

  // Save users to localStorage whenever they change
  useEffect(() => {
    localStorage.setItem("users", JSON.stringify(users));
  }, [users]);

  return (
    <Router>
      <Routes>
        {/* User List Route */}
        <Route
          path="/"
          element={<UserList users={users} setUsers={setUsers} />}
        />
        {/* User Details Route */}
        <Route
          path="/user/:id"
          element={<UserDetails users={users} setUsers={setUsers} />}
        />
        {/* Edit User Route */}
        <Route
          path="/edit/:id"
          element={<EditUser users={users} setUsers={setUsers} />}
        />
      </Routes>
    </Router>
  );
};

export default App;
